Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3395)

Unified Diff: cc/test/ordered_simple_task_runner.cc

Issue 935333002: Update from https://crrev.com/316786 (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/test/ordered_simple_task_runner.h ('k') | cc/test/pixel_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/test/ordered_simple_task_runner.cc
diff --git a/cc/test/ordered_simple_task_runner.cc b/cc/test/ordered_simple_task_runner.cc
index 852396eace3aa735b59fea931feb6d422bebacdd..e337909315f3f807c059b96cee07aeb314f736bd 100644
--- a/cc/test/ordered_simple_task_runner.cc
+++ b/cc/test/ordered_simple_task_runner.cc
@@ -60,16 +60,16 @@ bool TestOrderablePendingTask::operator<(
return ShouldRunBefore(other);
}
-scoped_refptr<base::debug::ConvertableToTraceFormat>
+scoped_refptr<base::trace_event::ConvertableToTraceFormat>
TestOrderablePendingTask::AsValue() const {
- scoped_refptr<base::debug::TracedValue> state =
- new base::debug::TracedValue();
+ scoped_refptr<base::trace_event::TracedValue> state =
+ new base::trace_event::TracedValue();
AsValueInto(state.get());
return state;
}
void TestOrderablePendingTask::AsValueInto(
- base::debug::TracedValue* state) const {
+ base::trace_event::TracedValue* state) const {
state->SetInteger("id", task_id_);
state->SetInteger("run_at", GetTimeToRun().ToInternalValue());
state->SetString("posted_from", location.ToString());
@@ -255,17 +255,17 @@ bool OrderedSimpleTaskRunner::RunForPeriod(base::TimeDelta period) {
return RunUntilTime(now_src_->Now() + period);
}
-// base::debug tracing functionality
-scoped_refptr<base::debug::ConvertableToTraceFormat>
+// base::trace_event tracing functionality
+scoped_refptr<base::trace_event::ConvertableToTraceFormat>
OrderedSimpleTaskRunner::AsValue() const {
- scoped_refptr<base::debug::TracedValue> state =
- new base::debug::TracedValue();
+ scoped_refptr<base::trace_event::TracedValue> state =
+ new base::trace_event::TracedValue();
AsValueInto(state.get());
return state;
}
void OrderedSimpleTaskRunner::AsValueInto(
- base::debug::TracedValue* state) const {
+ base::trace_event::TracedValue* state) const {
state->SetInteger("pending_tasks", pending_tasks_.size());
state->BeginArray("tasks");
« no previous file with comments | « cc/test/ordered_simple_task_runner.h ('k') | cc/test/pixel_test.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698